@@ -13,14 +13,14 @@ DATE=""
 for i in $(seq 1 60)
 do
     if date -v -1d > /dev/null 2>&1; then
-        DATE=$(date -v-${i}d "+%d-%m-%Y")
+        DATE=$(TZ=UTC date -u -v-${i}d "+%d-%m-%Y")
     else
-        DATE=$(date "+%d-%m-%Y" --date "$i day ago")
+        DATE=$(TZ=UTC date --utc "+%d-%m-%Y" --date "$i day ago")
     fi
     echo "x" > test.log-$DATE
 done
 
-$RLR test-config.56 --force
+$RLR test-config.56 --force || exit 23
 
 if [ -e test.log-$DATE ]; then
     echo "File test.log-$DATE should not exist (it should be deleted)"
